<?php
/*
 * ----------------------------------------------------------------------------
 * Va-Events.inc.php                                                 01/31/2003
 * This script will retrieve all of the informaton related to the configured
 * events that are found in EVENTS.CFG.
 * ----------------------------------------------------------------------------
 * Copyright (C) 2002-2003 Steve Winn. All Rights Reserved.
 *
 * The source code contains a fair amount of comments, which may aid anyone
 * attempting to follow the program or to modify it.
 *
 * For licensing and copyright information, view LICENSE.TXT.
 * ----------------------------------------------------------------------------
 */

require_once("va-functions.inc.php");       // A VADV-PHP script.


/**
* Va-Events.inc.php :: GetEvents()
*
* Retrieve all of the events information and store it into a multidimensional
* array.
*
* Array format: $event[1]["setting"]
*               $event[0] = Total number of events.
*
*/
function GetEvents() {
    $fileString = ReadEvents();
    if (!$fileString) trigger_error(VA_Error(3));

    $string = "tmp";
    $events = array();                      // Create the array.

    for ($x = 0; $string <> ""; $x++) {
        $offset = 45 * $x;
        $string = GetString($fileString, $offset + 1, 5);
        if ($string <> "") {
            $events[$x + 1]["time"]    = GetString($fileString, 1 + $offset, 5);
            $events[$x + 1]["date"]    = GetString($fileString, 6 + $offset, 6);
            $events[$x + 1]["type"]    = GetInteger($fileString, 12 + $offset);
            $events[$x + 1]["command"] = GetString($fileString, 14 + $offset, 32);
        }
    }

    $events[0] = $x - 1;                    // Put the number of doors in position 0.

    return $events;                         // Return the events.

}


/**
* Va-Events.inc.php :: PutEvents()
*
* This function will change the events.cfg to match the configuration variable
* passed. It then returns the new file string. The configuration variable MUST
* be in the format of $variable[1]["setting"].
*
*/
function PutEvents($fileString, $configVariable) {
    if (!is_string($fileString))    trigger_error(VA_Error(1));
    if (!is_array($configVariable)) trigger_error(VA_Error(1));

    $length  = count($configVariable);      // Get the number of elements in the config variable.
    $pointer = 0;                           // Reset the pointer.

    for ($x = 0; $pointer < $length; $x++) {
        $offset = 45 * $x;
        if (isset($configVariable[$x + 1])) {
            $pointer++;
            if (isset($configVariable[$x + 1]["time"]))    $fileString = PutString($fileString, $configVariable[$x + 1]["time"], 1 + $offset, 5);
            if (isset($configVariable[$x + 1]["date"]))    $fileString = PutString($fileString, $configVariable[$x + 1]["date"], 6 + $offset, 6);
            if (isset($configVariable[$x + 1]["type"]))    $fileString = PutInteger($fileString, $configVariable[$x + 1]["type"], 12 + $offset);
            if (isset($configVariable[$x + 1]["command"])) $fileString = PutString($fileString, $configVariable[$x + 1]["command"], 14 + $offset, 32);
        }
    }

    return $fileString;                     // Return the new file string.
}


/**
* Va-Events.inc.php :: ReadEvents()
*
* This function will read the events.cfg file.
*
*/
function ReadEvents() {
    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS["main"] . '\events.cfg';
    if (!is_file($file)) return FALSE;

    $fileString = ReadCfgFile($file);       // Read the file.

    return $fileString;                     // Return the file string.
}


/**
* Va-Events.inc.php :: WriteEvents()
*
* This function will write a new events.cfg file based on the file string
* passed to it. If the file string is not in the correct format, then your
* events.cfg file will become corrupt and the BBS could stop functioning!
*
*/
function WriteEvents($fileString) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));

    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS["main"] . '\events.cfg';
    if (!is_file($file)) return FALSE;

    $status = WriteCfgFile($file, $fileString);

    return $status;                         // Return the result status.
}


// Retrieve the events automatically.
$VA_EVENTS = GetEvents();

?>
