<?php
/*
 * ----------------------------------------------------------------------------
 * Va-Functions.inc.php                                              01/31/2003
 * This script contains a set of functions that will make it easier to get
 * information from the Virtual Advanced configuration and data files. It also
 * contains basic functions to aid you when creating new scripts.
 * ----------------------------------------------------------------------------
 * Copyright (C) 2002-2003 Steve Winn. All Rights Reserved.
 *
 * The source code contains a fair amount of comments, which may aid anyone
 * attempting to follow the program or to modify it.
 *
 * For licensing and copyright information, view LICENSE.TXT.
 * ----------------------------------------------------------------------------
 */

session_name("VADVPHP");
session_start();

if (ini_get("register_globals")) die("ERROR(1) - Misconfiguration in PHP.INI. Please inform the webmaster.");
//if (ini_get("output_handler") == "") ob_start("ob_gzhandler");

require_once("va-syspaths.inc.php");        // Include the BBS's paths.


/**
* Va-Functions.inc.php :: ReadCfgFile()
*
* This function will read the entire file specified into one variable.
*
*/
function ReadCfgFile($file) {
    // Check to see if the file exists, if not return FALSE.
    if (!is_file($file)) return "";  // If file is missing, then it is blank.

    $length = filesize($file);              // Determine the length of the file.

    $fp = fopen($file, "r");                // Open the file.
    $fileString = fread($fp, $length);      // Read the entire length into a variable.
    fclose($fp);                            // Close the file.

    return $fileString;                     // Return the file string.
}


/**
* Va-Functions.inc.php :: WriteCfgFile()
*
* This function will create a new configuration file based on the file string
* passed.
*
*/
function WriteCfgFile($file, $fileString) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));
    
    $length = strlen($fileString);          // Determine the length of the file string.
    
    $fp = fopen($file, "w");                // Open the file.
    flock($fp, 2);                          // Lock the file.

    $status = fwrite($fp, $fileString, $length);    // Write the new file.

    flock($fp, 3);                          // Unlock the file.
    fclose($fp);                            // Close the file.
    
    return $status;                         // Return the write status.
}


/**
* Va-Functions.inc.php :: GetString()
*
* This function will take the given file string and extract the string value
* by using its position and length.
*
*/
function GetString($fileString, $position, $length) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));
    if ((!is_int($position))     && (!is_string($position))) trigger_error(VA_Error(1));
    if ((!is_int($length))       && (!is_string($length)))   trigger_error(VA_Error(1));

    // Check to see if the variable was passed, if not then return nothing.
    if ($fileString == "") return "";

    // Check to see if the position is larger than the string length.
    if ($position > strlen($fileString)) return "";

    $position--;                            // Reduce the position by one.
    $string = trim(substr($fileString, $position, $length));

    return $string;                         // Return the string.
}


/**
* Va-Functions.inc.php :: GetChar()
*
* This function will take the given file string and extract the character value
* by using its position.
*
*/
function GetChar($fileString, $position) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));
    if ((!is_int($position))     && (!is_string($position))) trigger_error(VA_Error(1));

    // Check to see if the variable was passed, if not then return nothing.
    if ($fileString == "") return "";

    // Check to see if the position is larger than the string length.
    if ($position > strlen($fileString)) return 0;

    $position--;                            // Reduce the position by one.
    // Get the first ascii value.
    $a = ord(substr($fileString, $position, 1));

    return $a;                              // Return the integer.
}


/**
* Va-Functions.inc.php :: GetInteger()
*
* This function will take the given file string and extract the integer value
* by using its position.
*
*/
function GetInteger($fileString, $position) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));
    if ((!is_int($position))     && (!is_string($position))) trigger_error(VA_Error(1));

    // Check to see if the variable was passed, if not then return nothing.
    if ($fileString == "") return "";

    // Check to see if the position is larger than the string length.
    if ($position > strlen($fileString)) return 0;

    $position--;                            // Reduce the position by one.
    // Get the first ascii value.
    $a = ord(substr($fileString, $position, 1));

    $position++;                            // Move to the next position.
    // Get the second ascii value.
    $b = 256 * (ord(substr($fileString, $position, 1)));

    return $a + $b;                         // Return the integer.
}


/**
* Va-Functions.inc.php :: GetLongInt()
*
* This function will take the given file string and extract the long integer
* value by using its position.
*
*/
function GetLongInt($fileString, $position) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));
    if ((!is_int($position))     && (!is_string($position))) trigger_error(VA_Error(1));

    // Check to see if the variable was passed, if not then return nothing.
    if ($fileString == "") return "";
    
    // Check to see if the position is larger than the string length.
    if ($position > strlen($fileString)) return 0;
    
    $position--;                            // Reduce the position by one.
    // Get the first ascii value.
    $a = ord(substr($fileString, $position, 1));
    
    $position++;                            // Move to the next position.
    // Get the second ascii value.
    $b = 256 * (ord(substr($fileString, $position, 1)));

    $position++;                            // Move to the next position.
    // Get the third ascii value.
    $c = 65536 * (ord(substr($fileString, $position, 1)));
    
    $position++;                            // Move to the next position.
    // Get the fourth ascii value.
    $d = 16777216 * (ord(substr($fileString, $position, 1)));
    
    return $a + $b + $c + $d;               // Return the long integer.
}


/**
* Va-Functions.inc.php :: GetSingle()
*
* This function will take the given file string and extract the single precison
* value by using its position.
*
*/
function GetSingle($fileString, $position) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));
    if ((!is_int($position))     && (!is_string($position))) trigger_error(VA_Error(1));

// ** It has not been determined how to extract this value! **
}


/**
* Va-Functions.inc.php :: PutString()
*
* This function will put the passed string into the file string at the given
* position.
*
*/
function PutString($fileString, $string, $position, $length) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));
    if (!is_string($string))     trigger_error(VA_Error(1));
    if ((!is_int($position))     && (!is_string($position))) trigger_error(VA_Error(1));
    if ((!is_int($length))       && (!is_string($length)))   trigger_error(VA_Error(1));
    
    $position--;

    if (strlen($string) < $length) {
        $string = str_pad($string, $length);
    } else {
        $string = substr($string, 0, $length);
    }
    $fileString = substr_replace($fileString, $string, $position, $length);
    
    return $fileString;                     // Return the new string.
}


/**
* Va-Functions.inc.php :: PutChar()
*
* This function will put the passed integer into the file string at the given
* position. This is used for writing characters, or one byte integers.
*
*/
function PutChar($fileString, $int, $position) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));
    if ((!is_int($int))          && (!is_string($position))) trigger_error(VA_Error(1));
    if ((!is_int($position))     && (!is_string($length)))   trigger_error(VA_Error(1));

    $position--;

    $int = MakeChar($int);
    $fileString = substr_replace($fileString, $int, $position, 1);

    return $fileString;                     // Return the new string.
}


/**
* Va-Functions.inc.php :: PutInteger()
*
* This function will put the passed integer into the file string at the given
* position. This is used for writing two byte integers.
*
*/
function PutInteger($fileString, $int, $position) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));
    if ((!is_int($int))          && (!is_string($int)))      trigger_error(VA_Error(1));
    if ((!is_int($position))     && (!is_string($position))) trigger_error(VA_Error(1));

    $position--;

    $int = MakeInteger($int);
    $fileString = substr_replace($fileString, $int, $position, 2);

    return $fileString;                     // Return the new string.
}


/**
* Va-Functions.inc.php :: PutLongInt()
*
* This function will put the passed integer into the file string at the given
* position. This is used for writing four byte integers.
*
*/
function PutLongInt($fileString, $int, $position) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));
    if ((!is_int($int))          && (!is_string($int)))      trigger_error(VA_Error(1));
    if ((!is_int($position))     && (!is_string($position))) trigger_error(VA_Error(1));

    $position--;

    $int = MakeLongInt($int);
    $fileString = substr_replace($fileString, $int, $position, 4);

    return $fileString;                     // Return the new string.
}


/**
* Va-Functions.inc.php :: PutSingle()
*
* This function will put the passed single precision value into the file string
* at the given position.
*
*/
function PutSingle($fileString, $int, $position) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));
    if ((!is_int($int))          && (!is_string($int)))      trigger_error(VA_Error(1));
    if ((!is_int($position))     && (!is_string($position))) trigger_error(VA_Error(1));

// ** It has not been determined how to extract this value, let alone write it! **
}


/**
* Va-Functions.inc.php :: MakeChar()
*
* This function will take the value given and convert it into a one byte
* integer represented by ascii characters.
*
*/
function MakeChar($value) {
    if ((!is_int($value)) && (!is_string($value))) trigger_error(VA_Error(1));
    
    if ($value == 0)  return chr(0);
    if ($value > 256) trigger_error(VA_Error(2));
    
    $a = chr($value);                       // Set the variable to the ascii character.
    
    return $a;                              // Return the character.
}


/**
* Va-Functions.inc.php :: MakeInteger()
*
* This function will take the value given and convert it into a two byte
* integer represented by ascii characters.
*
*/
function MakeInteger($value) {
    if ((!is_int($value)) && (!is_string($value))) trigger_error(VA_Error(1));

    if ($value == 0)    return chr(0) . chr(0);
    if ($value > 32767) trigger_error(VA_Error(2));
    
    $b = intval($value / 256);              // Divide the value.
    if ($b >= 1) {                          // If the new value was divisible...
        $b = chr($b);                       // Set the variable to the ascii character.
        $value = $value - $b;               // Subtract the variable from the value.
    } else {
        $b = chr(0);                        // If it was not divisible, set it to null.
    }

    $a = chr($value);                       // Set the variable to the ascii character.

    return $a . $b;                         // Return the ascii representation.
}


/**
* Va-Functions.inc.php :: MakeLongInt()
*
* This function will take the value given and convert it into a four byte
* long integer represented by ASCII characters.
*
*/
function MakeLongInt($value) {
    if ((!is_int($value)) && (!is_string($value))) trigger_error(VA_Error(1));

    if ($value == 0)         return chr(0) . chr(0) . chr(0) . chr(0);
    if ($value > 2147483647) trigger_error(VA_Error(2));
    
    $d = intval($value / 16777216);         // Divide the value.
    if ($d >= 1) {                          // If the new value was divisible...
        $d = chr($d);                       // Set the variable to the ascii character.
        $value = $value - $d;               // Subtract the variable from the value.
    } else {
        $d = chr(0);                        // If it was not divisible, set it to null.
    }

    $c = intval($value / 65536);            // Divide the value.
    if ($c >= 1) {                          // If the new value was divisible...
        $c = chr($c);                       // Set the variable to the ascii character.
        $value = $value - $c;               // Subtract the variable from the value.
    } else {
        $c = chr(0);                        // If it was not divisible, set it to null.
    }
    
    $b = intval($value / 256);              // Divide the value.
    if ($b >= 1) {                          // If the new value was divisible...
        $b = chr($b);                       // Set the variable to the ascii character.
        $value = $value - $b;               // Subtract the variable from the value.
    } else {
        $b = chr(0);                        // If it was not divisible, set it to null.
    }
    
    $a = chr($value);                       // Set the variable to the ascii character.

    return $a . $b . $c . $d;               // Return the ascii representation.
}


/**
* Va-Functions.inc.php :: ReadConfig()
*
* This function will read a configuration file and place its variables into
* an array.
*
* The type of configuration file has comments designated by a semicolon, and
* variables are assigned like 'variable="value"'.
*
*/
function ReadConfig($configFile) {
    // If the configfile is missing, return the default values.
    if (!is_file($configFile)) trigger_error("File is missing.");

    // Read the configfile into an array.
    $fp = fopen($configFile, "r");          // Open the configfile.
    $x  = 1;

    while (!feof($fp)) {
        $line    = trim(fgets($fp));        // Read a line.
        $comment = trim(substr($line, 0, 1));
        if ($comment != ";") {
            if ($line != "") {
                $var[$x] = $line;           // Add the line into the array.
                $x++;                       // Increase the array. Used below too as a counter.
            }
        }
    }

    fclose($fp);                            // Close the configfile.

    if (!isset($var)) return $config;  // Check to see if any values were read.

    // The configuration is now in an array, so lets set the proper variables
    // with the information.

    for ($y = 1; $y != $x; $y++) {                              // Examine the array and set new values.
        $pos   = strpos($var[$y], "=");                         // Determine the position of the equal symbol.
        $desc  = trim(strtolower(substr($var[$y], 0, $pos)));   // Determine the variable description.
        $value = trim(substr($var[$y], $pos + 1));              // Determine the variable value.
        $value = str_replace(" ", "", $value);                  // Remove any spaces.
        $config[$desc] = strtolower($value);
    }

    return $config;                         // Return the configuration array.
}


/**
* Va-Functions.inc.php :: ReadAt2kConfig($configFile)
*
* This function will read an AT2k script configuration file, which usually is
* stored in the BBS's TXT directory.
*
* The configuration file has comments designated by a semicolon, and values are
* positioned based (they must appear in the file in a certain order and are not
* assigned to variables).
*
*/
function ReadAt2kConfig($configFile) {
    // If the configfile is missing, send an error.
    if (!is_file($configFile)) trigger_error("File is missing.");

    // Read the configfile into an array.
    $fp = fopen($configFile, "r");          // Open the configfile.
    $x  = 1;

    while (!feof($fp)) {
        $line    = trim(fgets($fp));        // Read a line.
        $comment = trim(substr($line, 0, 1));
        if ($comment != ";") {
            if ($line != "") {
                $var[$x] = $line;           // Add the line into the array.
                $x++;                       // Increase the array. Used below too as a counter.
            }
        }
    }

    fclose($fp);                            // Close the configfile.
    
    return $var;
}


/**
* Va-Functions.inc.php :: rnd()
*
* Returns a floating point number rounded to the specified number of decimal places.
*
*/
function rnd($float, $dec) {
    if ($dec == 0) {
        return round($float);
    } else {
        return floor($float * pow(10, $dec) + 0.5) / pow(10, $dec);
    }
}


/**
* Va-Functions.inc.php :: FixHeartColors()
*
* This routine will take $string and replace any heart codes within the string
* with html color codes.
*
*/
function FixHeartColors($string) {
    if (!is_string($string)) trigger_error(VA_Error(1));
    
    // Check to see if the variable was passed, if not then return the string.
    if ($string == "") return $string;
    
  	$string = str_replace(chr(3) . "0", "<font color=\"#ADAAAD\">", $string);
   	$string = str_replace(chr(3) . "1", "<font color=\"#52FFFF\">", $string);
   	$string = str_replace(chr(3) . "2", "<font color=\"#FFFF52\">", $string);
   	$string = str_replace(chr(3) . "3", "<font color=\"#AD00AD\">", $string);
   	$string = str_replace(chr(3) . "4", "<font color=\"#FFFFFF\">", $string);
   	$string = str_replace(chr(3) . "5", "<font color=\"#52FF52\">", $string);
   	$string = str_replace(chr(3) . "6", "<font color=\"#FF5552\">", $string);
   	$string = str_replace(chr(3) . "7", "<font color=\"#5255FF\">", $string);
   	$string = str_replace(chr(3) . "8", "<font color=\"#AD5500\">", $string);
   	$string = str_replace(chr(3) . "9", "<font color=\"#00AAAD\">", $string);
   	$string = str_replace(chr(3) . "a", "<font color=\"#00AA00\">", $string);
   	$string = str_replace(chr(3) . "b", "<font color=\"#FF55FF\">", $string);
   	$string = str_replace(chr(3) . "c", "<font color=\"#FFFFFF\">", $string);
   	$string = str_replace(chr(3) . "d", "<font color=\"#FFFF52\">", $string);
   	$string = str_replace(chr(3) . "e", "<font color=\"#52FFFF\">", $string);
   	$string = str_replace(chr(3) . "f", "<font color=\"#ADAAAD\">", $string);
   	$string = str_replace(chr(3) . "g", "<font color=\"#5255FF\">", $string);
   	$string = str_replace(chr(3) . "h", "<font color=\"#FF5552\">", $string);
   	$string = str_replace(chr(3) . "i", "<font color=\"#5255FF\">", $string);
   	$string = str_replace(chr(3) . "j", "<font color=\"#FFFF52\">", $string);
   	$string = str_replace(chr(3) . "k", "<font color=\"#52FFFF\">", $string);
   	$string = str_replace(chr(3) . "l", "<font color=\"#ADAAAD\">", $string);
   	$string = str_replace(chr(3) . "m", "<font color=\"#FFFFFF\">", $string);
   	$string = str_replace(chr(3) . "n", "<font color=\"#ADAAAD\">", $string);
   	$string = str_replace(chr(3) . "o", "<font color=\"#ADAAAD\">", $string);
   	$string = str_replace(chr(3) . "p", "<font color=\"#AD0000\">", $string);
   	$string = str_replace(chr(3) . "q", "<font color=\"#0000AD\">", $string);
   	$string = str_replace(chr(3) . "r", "<font color=\"#FFFFFF\">", $string);
   	$string = str_replace(chr(3) . "s", "<font color=\"#FF5552\">", $string);
   	$string = str_replace(chr(3) . "t", "<font color=\"#5255FF\">", $string);
   	$string = str_replace(chr(3) . "u", "<font color=\"#FFFFFF\">", $string);
   	$string = str_replace(chr(3) . "v", "<font color=\"#ADAAAD\">", $string);
   	$string = str_replace(chr(3) . "w", "<font color=\"#ADAAAD\">", $string);
   	$string = str_replace(chr(3) . "x", "<font color=\"#ADAAAD\">", $string);
   	$string = str_replace(chr(3) . "y", "<font color=\"#FFFFFF\">", $string);
   	$string = str_replace(chr(3) . "z", "<font color=\"#FFFFFF\">", $string);
   	$string = str_replace(chr(3) . "A", "<font color=\"#00AA00\">", $string);
   	$string = str_replace(chr(3) . "B", "<font color=\"#FF55FF\">", $string);
   	$string = str_replace(chr(3) . "C", "<font color=\"#FFFFFF\">", $string);
   	$string = str_replace(chr(3) . "D", "<font color=\"#FFFF52\">", $string);
   	$string = str_replace(chr(3) . "E", "<font color=\"#52FFFF\">", $string);
   	$string = str_replace(chr(3) . "F", "<font color=\"#ADAAAD\">", $string);
   	$string = str_replace(chr(3) . "G", "<font color=\"#5255FF\">", $string);
   	$string = str_replace(chr(3) . "H", "<font color=\"#FF5552\">", $string);
   	$string = str_replace(chr(3) . "I", "<font color=\"#5255FF\">", $string);
   	$string = str_replace(chr(3) . "J", "<font color=\"#FFFF52\">", $string);
   	$string = str_replace(chr(3) . "K", "<font color=\"#52FFFF\">", $string);
   	$string = str_replace(chr(3) . "L", "<font color=\"#ADAAAD\">", $string);
   	$string = str_replace(chr(3) . "M", "<font color=\"#FFFFFF\">", $string);
   	$string = str_replace(chr(3) . "N", "<font color=\"#ADAAAD\">", $string);
   	$string = str_replace(chr(3) . "O", "<font color=\"#ADAAAD\">", $string);
   	$string = str_replace(chr(3) . "P", "<font color=\"#AD0000\">", $string);
   	$string = str_replace(chr(3) . "Q", "<font color=\"#0000AD\">", $string);
   	$string = str_replace(chr(3) . "R", "<font color=\"#FFFFFF\">", $string);
   	$string = str_replace(chr(3) . "S", "<font color=\"#FF5552\">", $string);
   	$string = str_replace(chr(3) . "T", "<font color=\"#5255FF\">", $string);
   	$string = str_replace(chr(3) . "U", "<font color=\"#FFFFFF\">", $string);
   	$string = str_replace(chr(3) . "V", "<font color=\"#ADAAAD\">", $string);
   	$string = str_replace(chr(3) . "W", "<font color=\"#ADAAAD\">", $string);
   	$string = str_replace(chr(3) . "X", "<font color=\"#ADAAAD\">", $string);
   	$string = str_replace(chr(3) . "Y", "<font color=\"#FFFFFF\">", $string);
   	$string = str_replace(chr(3) . "Z", "<font color=\"#FFFFFF\">", $string);
   	$string = str_replace(chr(3) . "[", "<font color=\"#525552\">", $string);
   	$string = trim($string) . "</font>";

   	return $string;                         // Return the new string.
}


/**
* Va-Functions.inc.php :: StripHeartColors()
*
* This routine will take $string and remove any heart codes within the string.
* It also removes diamond codes.
*
*/
function StripHeartColors($string) {
    if (!is_string($string)) trigger_error(VA_Error(1));
    
    // Check to see if the variable was passed, if not then return the string.
    if ($string == "") return $string;

    $string = " " . $string;

    // Search for hearts.
    $position = 1;
    while ($position) {
        $position = strpos($string, chr(3), 1);
        if ($position) $string = substr_replace($string, "", $position, 2);
    }
    
    // Search the file for diamonds.
    $position = 1;
    while ($position) {
        $position = strpos($string, chr(4), 1);
        if ($position) $string = substr_replace($string, "", $position, 2);
    }

   	return trim($string);                   // Return the new string.
}


/**
* Va-Functions.inc.php :: StripRouting()
*
* This function will take $string and remove the lines that begin with a
* diamond code. Later it will check user security level and display the string
* accordingly.
*
*/
function StripRouting($string) {
    if (!is_string($string)) trigger_error(VA_Error(1));
    
    // Check to see if the variable was passed, if not then return the string.
    if ($string == "") return $string;

    $string = " " . $string;
    
    // Search for diamonds.
    $position = 1;
    while ($position) {
        $position = strpos($string, chr(4), 0);
        if ($position) {
            $endPosition = strpos($string, chr(10), $position);
            $string      = substr_replace($string, "", $position, ($endPosition - $position));
        }
    }
    
    // Search the rest of the file for diamonds.
    $position = 1;
    while ($position) {
        $position = strpos($string, chr(4), 1);
        if ($position) {
            $endPosition = strpos($string, chr(10), $position);
            $string      = substr_replace($string, "", $position, ($endPosition - $position + 1));
        }
    }

    return trim($string);                   // Return the new string.
}


/**
* Va-Functions.inc.php :: HtmlEncode()
*
* This function will take the passed line and add html href information for any
* links found. It will search for http://, ftp://, mailto: and telnet://.
*
*/
function HTMLEncode($text) {
    $text = " " . $text;
    $text = preg_replace(array(
                               "/( )(([\w\.]+))(@)([\w\.]+)\b/i",
                               "/((ftp(7?):\/\/)|(ftp\.))([\w\.\/\&\=\?\-~:]+)/",
                               "/(http(s?):\/\/)([\w\.\/\&\=\?\-~:]+)/",
                               "/( )(www\.)([\w\.\/\&\=\?\-~:]+)/",
                               "/(telnet:\/\/)([\w\.\/\&\=\?\-:]+)/"
                              ),
                         array(
                               " <a href=\"mailto:$3$4$5\"\">$3$4$5</a>",
                               "<a href=\"ftp$3://$4$5\" target=\"_blank\">ftp://$4$5</a>",
                               "<a href=\"http:$2//$3\" target=\"_blank\">$1$3</a>",
                               " <a href=\"http://$2$3\" target=\"_blank\">$2$3</a>",
                               "<a href=\"telnet://$2$3\">telnet://$2$3</a>"
                              ),
                              $text);

    return trim($text);
}


/**
* Va-Functions.inc.php :: ConvertDate()
*
* This function will convert full dates into an abbreviated date.
*
*/
function ConvertDate($date) {
    // Check to see if the variable was passed, if not then return the date.
    if ($date == "") return $date;

    $newdate = trim(substr($date, 4));
    $day = substr($newdate, 4, 1);
    if ($day == 0) $newdate = substr_replace($newdate, "", 4, 1);

    // Check to see if the date format was wrong (includes time) and fix it.
    $pos = strpos($newdate, ":", 0);
    if ($pos != "") {
        $date = substr($newdate, 0, $pos - 3);
        $hour = substr($newdate, $pos - 2, 2);
        $min  = substr($newdate, $pos + 1, 2);

        if ($hour > 12) {
            $hour    = $hour - 12;
            $newdate = $date . " " . $hour . ":" . $min . " PM";
        } else if ($hour == 0) {
            $newdate = $date . " 12:" . $min . " AM";
        } else {
            $newdate = $date . " " . $hour . ":" . $min . " AM";
        }
    }
    
    return trim($newdate);
}


/**
* Va-Functions.inc.php :: ConvertTime()
*
* This function will convert the 24 hour format into the 12 hour format.
*
*/
function ConvertTime($time) {
    // Check to see if the variable was passed, if not then return the time.
    if ($time == "") return $time;

    $pos  = strpos($time, ":", 0);
    if ($pos == "") return "";
    $pos2 = strpos($time, ":", $pos + 1);
    $hour = substr($time, 0, $pos);
    $min  = substr($time, $pos + 1, ($pos2 - $pos - 1));

    if ($hour > 12) {
        $hour    = $hour - 12;
        $newtime = $hour . ":" . $min . " PM";
    } else if ($hour == 0) {
        $newtime = "12:" . $min . " AM";
    } else {
        $tmp = substr($hour, 0, 1);
        if ($tmp == 0) $hour = substr_replace($hour, "", 0, 1);
        $newtime = $hour . ":" . $min . " AM";
    }

    return trim($newtime);
}


/**
* Va-Functions.inc.php :: ConvertDateTime()
*
* This function take the time and date and format them into a string with all
* needed fixes. It will place the result into an array.
*
*/
function ConvertDateTime($date, $time) {
    $dateTime["date"] = $date;
    $dateTime["time"] = $time;
    
    // Check to see if the variable was passed, if not then return the date and time.
    if ($date == "") return $dateTime;
    if ($time == "") return $dateTime;

    $position = strpos($time, ":", 0);
    if ($position == "") {
        $position  = strpos($date, ",", 0);
        if ($position == "") {
            $sec   = trim(substr($time, 0, 2));
            $year  = trim(substr($time, 3, 4));
            $time  = trim(substr($date, 12) . ":" . $sec);
            $date  = trim(substr($date, 0, 10) . ", " . $year);
        } else {
            $dow   = trim(substr($date, 0, 3));
            $day   = trim(substr($date, 5, 2));
            $month = trim(substr($date, 7, 4));
            $year  = trim(substr($date, 11));
            if (strpos($year, ",", 0) != "") $year = substr($year, 0, 4);
            $date  = $dow . " " . $month . " " . $day . ", " . $year;
            $time  = "00:00:00";
        }
    }
    else {
        $position = strpos($date, ",", 0);
        if ($position != "") {
            $tmp = substr($date, 8, 2);
            if (!is_numeric($tmp)) {
                $position = 0;
                $dow   = substr($date, 0, 3);
                $day   = substr($date, 4, 2);
                if (strpos($day, " ", 0) != "") {
                    $day = "0" . substr($date, 4, 1);
                    $position--;
                }
                $month = substr($date, $position + 8, 3);
                $year  = substr($date, $position + 12);
                $date  = $dow . " " . $month . " " . $day . ", " . $year;
            } else if (strlen($date) < 16) {
                $date  = "Dow " . $date;
            }
        }
    }

    $year = trim(substr($date, 11));
    if ($year < 1970) {
        $tmp  = substr($year, 2, 2);
        $year = "20" . $tmp;
        $date = substr_replace($date, $year, 12, 4);
    }

    $dateTime["date"] = ConvertDate($date);
    $dateTime["time"] = ConvertTime($time);

    return $dateTime;                       // Return the date and time.
}


/**
* Va-Functions.inc.php :: GetAccFlags()
*
* This function will take the long integer value of the access flags and
* convert it into a string format.
*
*/
function GetAccFlags($accFlags) {
    if ((!is_int($accFlags)) && (!is_string($accFlags))) trigger_error(VA_Error(1));
    
    // Check to see if the variable was passed, if not then return nothing.
    if ($accFlags == "") return "";
    
    $flags  = "";                           // Flags start off as none.
    $num    = 33554432;                     // This is letter Z's value as a user flag.
    $letter = 90;                           // Set starting point at letter Z.

    while ($num >= 1) {
        $tmp = intval($accFlags / $num);
        if ($tmp >= 1) {
            $flags    = $flags . chr($letter);
            $accFlags = $accFlags - $num;
        }
        $num = $num / 2;
        $letter--;
    }

    return strrev($flags);                  // Return the access flags.
}


/**
* Va-Functions.inc.php :: WriteLog()
*
* This function will log a line into the specified file which is stored in
* the BBS's data directory. The logfile is a filename.
*
*/
function WriteLog($logFile, $line) {
    global $VA_SYSPATHS;

    $logFile = $VA_SYSPATHS["data"] . "\\" . $logFile;
    
    if (!is_file($logFile)) {
        $fp = fopen($logFile, "w");
        flock($fp, 2);
        fwrite($fp, "\r\n");
        fwrite($fp, "VADV-PHP Event Log\r\n");
        fwrite($fp, "-------------------------------------------------------------------------------\r\n");
        fwrite($fp, "Date           Time     IP Address        Description\r\n");
        fwrite($fp, "-------------------------------------------------------------------------------\r\n");
        flock($fp, 3);
        fclose($fp);
    }

    $fp = fopen($logFile, "a");
    flock($fp, 2);                          // Lock the file.

    $ip = "[" . $_SERVER["REMOTE_ADDR"] . "]";
    $ip = str_pad($ip, 16, " ");

    $date   = date("D") . " " . date("Y") . "-" . date("m") . "-" . date("d");
    $time   = date("H") . ":" . date("i") . ":" . date("s");
    $line   = $date . " " . $time . " " . $ip . "  " . $line . "\r\n";
    $status = fwrite($fp, $line);           // Write the line to the file.

    flock($fp, 3);                          // Unlock the file.
    fclose($fp);                            // Close the file.
    
    return $status;                         // Return the result.
 }


/**
* Va-Functions.inc.php :: GetCurrentURL()
*
* This function simply returns the full URL of the current script.
*
*/
function GetCurrentURL() {
    return "http://" . $_SERVER["HTTP_HOST"] . $_SERVER["PHP_SELF"];
}


/**
* Va-Functions.inc.php :: VA_Error()
*
* This function will return the specified error message.
*
*/
function VA_Error($errNum) {
    if ((!is_int($errNum)) && (!is_string($errNum))) $errNum = 4;

    switch ($errNum) {
        case 0:
            $errMsg = "File not found.";
            break;
        case 1:
            $errMsg = "Variable is not proper type.";
            break;
        case 2:
            $errMsg = "Value is out of range.";
            break;
        case 3:
            $errMsg = "Invalid Configuration.";
            break;
        case 4:
            $errMsg = "Unknown Error.";
            break;
    }
    
    return $errMsg;                         // Return the error message.
}


/**
* Va-Functions.inc.php :: CustomErrorHandler()
*
* This is a custom error handler in case all hell breaks loose.
*
*/
function CustomErrorHandler($errNumber, $errDescript, $errFile, $errLine) {
    $pos  = strrpos($errFile, chr(92)) + 1;
    $file = substr($errFile, $pos);
    print "<h2>An error has occurred! Please try again later.</h2>\n";
    print "<h4>Press your BACK button to return to the previous page.</h4>\n";
    print "<pre>Error number: $errNumber\n";
    print "Description: $errDescript\n";
    print "Script name: $file\n";
    print "Line number: $errLine</pre>\n";
    die();
}

set_error_handler("CustomErrorHandler");    // Execute the default error handler.
error_reporting(E_ALL);

?>
