<?php
/*
 * ----------------------------------------------------------------------------
 * Va-Network.inc.php                                                01/31/2003
 * This script will retrieve various information about configured networks.
 * ----------------------------------------------------------------------------
 * Copyright (C) 2002-2003 Steve Winn. All Rights Reserved.
 *
 * The source code contains a fair amount of comments, which may aid anyone
 * attempting to follow the program or to modify it.
 *
 * For licensing and copyright information, view LICENSE.TXT.
 * ----------------------------------------------------------------------------
 */

require_once("va-functions.inc.php");       // A VADV-PHP script.


/**
* Va-Networks.inc.php :: GetNetworkInfo()
*
* This function will return information about all networks that have been
* configured. Networks that have not been configured are ignored.
*
* Variable returned is in the format of: $var[number][settings][network config]
*
*/
function GetNetworkInfo() {
    global $VA_SYSPATHS;                    // Include system paths.
    
    $datFile = $VA_SYSPATHS["data"] . '\networks.lst';
    $netFile = $VA_SYSPATHS["data"] . '\net.';
    
    if (!is_file($datFile)) return FALSE;
    
    $cnt     = 1;
    $netInfo = array();
    $fp      = fopen($datFile, "r");        // Open the networks.lst file.
    
    while (!feof($fp)) {
        $line    = trim(fgets($fp));           // Read a line.
        $comment = trim(substr($line, 0, 1));
        if ($comment != ";") {
            $pos = strpos($line, ",");          // Determine the position of the comma.
            if ($pos != 0) {
                $num  = trim(substr($line, 0, $pos));   // Get the network number.
                $file = $netFile . $num;                // Create the filename.
                if (is_file($file)) {                   // If the file exists, the network is configured.
                    $netInfo[$num]["netno"]   = $num;

                    $pos++;
                    $pos2   = strpos($line, ",", $pos);     // Determine the next position.
                    $length = $pos2 - $pos;                 // Determine the length.
                    $netInfo[$num]["nettype"] = trim(substr($line, $pos, $length));

                    $pos    = $pos2 + 1;
                    $pos2   = strpos($line, ",", $pos);     // Determine the next position.
                    $length = $pos2 - $pos;                 // Determine the length.
                    $netInfo[$num]["desc"]    = trim(substr($line, $pos, $length));

                    $pos    = $pos2 + 1;
                    $pos2   = strpos($line, ",", $pos);     // Determine the next position.
                    $length = $pos2 - $pos;                 // Determine the length.
                    $netInfo[$num]["accflag"] = trim(substr($line, $pos, $length));
                    if ($netInfo[$num]["nettype"] == 4) {
                        $pos    = $pos2 + 1;
                        $pos2   = strpos($line, ",", $pos);     // Determine the next position.
                        $length = $pos2 - $pos;                 // Determine the length.
                        $netInfo[$num]["zone"]     = trim(substr($line, $pos, $length));

                        $pos    = $pos2 + 1;
                        $pos2   = strpos($line, ",", $pos);     // Determine the next position.
                        $length = $pos2 - $pos;                 // Determine the length.
                        $netInfo[$num]["nodelist"] = trim(substr($line, $pos, $length));

                        $pos    = $pos2 + 1;
                        $pos2   = strpos($line, ",", $pos);     // Determine the next position.
                        $length = $pos2 - $pos;                 // Determine the length.
                        $netInfo[$num]["nodediff"] = trim(substr($line, $pos, $length));

                        $pos    = $pos2 + 1;
                        $pos2   = strpos($line, ",", $pos);     // Determine the next position.
                        $length = $pos2 - $pos;                 // Determine the length.
                        $netInfo[$num]["misc"]     = trim(substr($line, $pos, $length));
                    }
                    $netSettings = ReadConfig($file);
                    $netInfo[$num]["settings"] = $netSettings;
                    $cnt++;
                }
            }
        }
    }
    
    fclose($fp);                            // Close the networks.lst file.
    
    $netInfo[0] = $cnt - 1;                 // Set the total number of configured networks.

    return $netInfo;                        // Return the network info.
}


/**
* Va-Networks.inc.php :: GetVnetInfo()
*
* This function will return information about the VirtualNet network, which
* is used more often than any other type of network.
*
* Variable returned is in the format of: $var[network config]
*
*/
function GetVnetInfo() {
    global $VA_SYSPATHS;                    // Include system paths.
    
    $file = $VA_SYSPATHS["data"] . '\net.1';
    
    if (!is_file($file)) {                  // If the file is missing, return the default values.
        $vnet["systemid"] = 0;
        return $vnet;
    }
    
    return ReadConfig($file);               // Read the file and return the info.
}

?>
