<?php
/*
 * ----------------------------------------------------------------------------
 * Va-QuickVal.inc.php                                               01/31/2003
 * This script will retrieve all of the informaton related to the configured
 * quick validation settings that are found in QUICKVAL.CFG.
 * ----------------------------------------------------------------------------
 * Copyright (C) 2002-2003 Steve Winn. All Rights Reserved.
 *
 * The source code contains a fair amount of comments, which may aid anyone
 * attempting to follow the program or to modify it.
 *
 * For licensing and copyright information, view LICENSE.TXT.
 * ----------------------------------------------------------------------------
 */

require_once("va-functions.inc.php");       // A VADV-PHP script.


/**
* Va-QuickVal.inc.php :: GetQuickVal()
*
* Retrieve all of the quick validation information and store it into a
* multidimensional array.
*
* Array format: $quickval[1]["setting"]
*               $quickval[0] = Total number of configured quickvals.
*
*/
function GetQuickVal() {
    $fileString = ReadQuickVal();
    if (!$fileString) trigger_error(VA_Error(3));

    $string   = "tmp";
    $quickval = array();                    // Create the array.

    for ($x = 0; $string <> ""; $x++) {
        $offset = 73 * $x;
        $string = GetInteger($fileString, $offset + 1);
        if ($string <> "") {
            $quickval[$x + 1]["seclevel"]  = GetInteger($fileString, 1 + $offset);
            $quickval[$x + 1]["timelimit"] = GetInteger($fileString, 3 + $offset);
            $quickval[$x + 1]["flags"]     = GetLongInt($fileString, 5 + $offset);
        }
    }

    $quickval[0] = $x - 1;                  // Put the number of doors in position 0.

    return $quickval;                       // Return the doors.

}


/**
* Va-QuickVal.inc.php :: PutQuickVal()
*
* This function will change the quickval.cfg to match the configuration variable
* passed. It then returns the new file string. The configuration variable MUST
* be in the format of $variable[1]["setting"].
*
*/
function PutQuickVal($fileString, $configVariable) {
    if (!is_string($fileString))    trigger_error(VA_Error(1));
    if (!is_array($configVariable)) trigger_error(VA_Error(1));

    $length  = count($configVariable);      // Get the number of elements in the config variable.
    $pointer = 0;                           // Reset the pointer.

    for ($x = 0; $pointer < $length; $x++) {
        $offset = 73 * $x;
        if (isset($configVariable[$x + 1])) {
            $pointer++;
            if (isset($configVariable[$x + 1]["seclevel"]))  $fileString = PutInteger($fileString, $configVariable[$x + 1]["seclevel"], 1 + $offset);
            if (isset($configVariable[$x + 1]["timelimit"])) $fileString = PutInteger($fileString, $configVariable[$x + 1]["timelimit"], 3 + $offset);
            if (isset($configVariable[$x + 1]["flags"]))     $fileString = PutLongInt($fileString, $configVariable[$x + 1]["flags"], 5 + $offset);
        }
    }

    return $fileString;                     // Return the new file string.
}


/**
* Va-QuickVal.inc.php :: ReadQuickVal()
*
* This function will read the quickval.cfg file.
*
*/
function ReadQuickVal() {
    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS["main"] . '\quickval.cfg';
    if (!is_file($file)) return FALSE;

    $fileString = ReadCfgFile($file);       // Read the file.

    return $fileString;                     // Return the file string.
}


/**
* Va-QuickVal.inc.php :: WriteQuickVal()
*
* This function will write a new quickval.cfg file based on the file string
* passed to it. If the file string is not in the correct format, then your
* upload.cfg file will become corrupt and the BBS could stop functioning!
*
*/
function WriteUpload($fileString) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));

    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS["main"] . '\quickval.cfg';
    if (!is_file($file)) return FALSE;

    $status = WriteCfgFile($file, $fileString);

    return $status;                         // Return the result status.
}


// Retrieve the quick validation settings automatically.
$VA_QUICKVAL = GetQuickVal();

?>
