<?php
/*
 * ----------------------------------------------------------------------------
 * Va-Random.inc.php                                                 01/31/2003
 * This script will retrieve all of the random quotes from the BBS's
 * RANDOM.CFG file and store them into a simple array.
 * ----------------------------------------------------------------------------
 * Copyright (C) 2002-2003 Steve Winn. All Rights Reserved.
 *
 * The source code contains a fair amount of comments, which may aid anyone
 * attempting to follow the program or to modify it.
 *
 * For licensing and copyright information, view LICENSE.TXT.
 * ----------------------------------------------------------------------------
 */

require_once("va-functions.inc.php");       // A VADV-PHP script.


/**
* Va-Random.inc.php :: GetRandomQuotes()
*
* This function will put all of the VADV random quotes into a simple array.
*
*/
function GetRandomQuotes() {
    $fileString = ReadRandom();
    if (!$fileString) trigger_error(VA_Error(3));

    $string = "tmp";
    $random = array();                      // Create the array.
    
    for ($x = 0; $string <> ""; $x++) {
        $offset = 210 * $x;
        $string = GetString($fileString, $offset + 1, 210);
        if ($string <> "") {
            $random[$x + 1] = GetString($fileString, 1 + $offset, 210);
        }
    }

    $random[0] = $x - 1;                    // Put the number of quotes in position 0.
    
    return $random;                         // Return the random quotes.
}


/**
* Va-Random.inc.php :: PutRandomQuotes()
*
* This function will change the random.cfg to match the configuration variable
* passed. It then returns the new file string. The configuration variable MUST
* be in the format of $variable[1].
*
*/
function PutRandomQuotes($fileString, $configVariable) {
    if (!is_string($fileString))    trigger_error(VA_Error(1));
    if (!is_array($configVariable)) trigger_error(VA_Error(1));

    $length  = count($configVariable);      // Get the number of elements in the config variable.
    $pointer = 0;                           // Reset the pointer.

    for ($x = 0; $pointer < $length; $x++) {
        $offset = 210 * $x;
        if (isset($configVariable[$x + 1])) {
            $pointer++;
            $fileString = PutString($fileString, $configVariable[$x + 1], 1 + $offset, 210);
        }
    }

    return $fileString;                     // Return the new file string.
}


/**
* Va-Random.inc.php :: ReadRandom()
*
* This function will read the random.cfg file.
*
*/
function ReadRandom() {
    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS["main"] . '\random.cfg';
    if (!is_file($file)) return FALSE;

    $fileString = ReadCfgFile($file);       // Read the file.

    return $fileString;                     // Return the file string.
}


/**
* Va-Download.inc.php :: WriteDownload()
*
* This function will write a new download.cfg file based on the file string
* passed to it. If the file string is not in the correct format, then your
* download.cfg file will become corrupt and the BBS could stop functioning!
*
*/
function WriteDownload($fileString) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));

    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS["main"] . '\download.cfg';
    if (!is_file($file)) return FALSE;

    $status = WriteCfgFile($file, $fileString);

    return $status;                         // Return the result status.
}


// Retrieve the random quotes automatically.
$VA_RANDOMQUOTES = GetRandomQuotes();
 
?>
