<?php
/*
 * ----------------------------------------------------------------------------
 * Va-Upload.inc.php                                                 01/31/2003
 * This script will retrieve all of the informaton related to the configured
 * upload protocols that are found in UPLOAD.CFG.
 * ----------------------------------------------------------------------------
 * Copyright (C) 2002-2003 Steve Winn. All Rights Reserved.
 *
 * The source code contains a fair amount of comments, which may aid anyone
 * attempting to follow the program or to modify it.
 *
 * For licensing and copyright information, view LICENSE.TXT.
 * ----------------------------------------------------------------------------
 */

require_once("va-functions.inc.php");       // A VADV-PHP script.


/**
* Va-Upload.inc.php :: GetUpload()
*
* Retrieve all of the upload protocol information and store it into a
* multidimensional array.
*
* Array format: $upload[1]["setting"]
*               $upload[0] = Total number of upload protocols.
*
*/
function GetUpload() {
    $fileString = ReadUpload();
    if (!$fileString) trigger_error(VA_Error(3));

    $string = "tmp";
    $upload = array();                      // Create the array.

    for ($x = 0; $string <> ""; $x++) {
        $offset = 73 * $x;
        $string = GetString($fileString, $offset + 1, 1);
        if ($string <> "") {
            $upload[$x + 1]["key"]     = GetString($fileString, 1 + $offset, 1);
            $upload[$x + 1]["desc"]    = GetString($fileString, 2 + $offset, 23);
            $upload[$x + 1]["batch"]   = GetInteger($fileString, 25 + $offset);
            $upload[$x + 1]["command"] = GetString($fileString, 26 + $offset, 48);
        }
    }

    $upload[0] = $x - 1;                    // Put the number of doors in position 0.

    return $upload;                         // Return the upload protocols.

}


/**
* Va-Upload.inc.php :: PutUpload()
*
* This function will change the upload.cfg to match the configuration variable
* passed. It then returns the new file string. The configuration variable MUST
* be in the format of $variable[1]["setting"].
*
*/
function PutUpload($fileString, $configVariable) {
    if (!is_string($fileString))    trigger_error(VA_Error(1));
    if (!is_array($configVariable)) trigger_error(VA_Error(1));

    $length  = count($configVariable);      // Get the number of elements in the config variable.
    $pointer = 0;                           // Reset the pointer.

    for ($x = 0; $pointer < $length; $x++) {
        $offset = 73 * $x;
        if (isset($configVariable[$x + 1])) {
            $pointer++;
            if (isset($configVariable[$x + 1]["key"]))     $fileString = PutString($fileString, $configVariable[$x + 1]["key"], 1 + $offset, 1);
            if (isset($configVariable[$x + 1]["desc"]))    $fileString = PutString($fileString, $configVariable[$x + 1]["desc"], 2 + $offset, 23);
            if (isset($configVariable[$x + 1]["batch"]))   $fileString = PutInteger($fileString, $configVariable[$x + 1]["batch"], 25 + $offset);
            if (isset($configVariable[$x + 1]["command"])) $fileString = PutString($fileString, $configVariable[$x + 1]["command"], 26 + $offset, 48);
        }
    }

    return $fileString;                     // Return the new file string.
}


/**
* Va-Upload.inc.php :: ReadUpload()
*
* This function will read the upload.cfg file.
*
*/
function ReadUpload() {
    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS["main"] . '\upload.cfg';
    if (!is_file($file)) return FALSE;

    $fileString = ReadCfgFile($file);       // Read the file.

    return $fileString;                     // Return the file string.
}


/**
* Va-Upload.inc.php :: WriteUpload()
*
* This function will write a new upload.cfg file based on the file string
* passed to it. If the file string is not in the correct format, then your
* upload.cfg file will become corrupt and the BBS could stop functioning!
*
*/
function WriteUpload($fileString) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));

    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS["main"] . '\upload.cfg';
    if (!is_file($file)) return FALSE;

    $status = WriteCfgFile($file, $fileString);

    return $status;                         // Return the result status.
}


// Retrieve the upload protocols automatically.
$VA_UPLOAD = GetUpload();

?>
